/***********************************************************************************************************************************
Harness for Testing Packs
***********************************************************************************************************************************/
#include "common/type/buffer.h"

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Convert Pack to String
String *hrnPackToStr(const Pack *pack);

// Convert PackRead to String
String *hrnPackReadToStr(PackRead *read);
